{% extends "jnt_admin_tools/dashboard/module.html" %}
{% load admin_tools_dashboard_tags %}
{% block module_content %}
<div class="group group-{{ module.display }}">
    {% spaceless %}
    {% if module.display == "tabs" %}
    <ul>
    {% for sub_module in module.children %}
        {% if not sub_module.is_empty %}<li class="group-tabs-link"><a href="#module_{{ sub_module.id }}">{{ sub_module.title|capfirst }}</a></li>{% endif %}
    {% endfor %}
    </ul>
    {% endif %}
    {% if module.display == "accordion" %}
    {% for sub_module in module.children %}
        {% if not sub_module.is_empty %}<span class="group-accordion-header"><a href="#">{{ sub_module.title|capfirst }}</a></span>{% endif %}
        {% admin_tools_render_dashboard_module sub_module %}
    {% endfor %}
    {% else %}
    {% for sub_module in module.children %}
        {% admin_tools_render_dashboard_module sub_module %}
    {% endfor %}
    {% endif %}
    {% endspaceless %}
</div>
{% endblock %}
